==> risk-center-api-0.5.10-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/ForgeSlotCfgDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
* 虚拟广告位配置表
*/
public class ForgeSlotCfgDto implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
    * 
    */
    private Long id;

    /**
    * 广告位ID
    */
    private Long slotId;

    /**
    * 媒体ID
    */
    private Long appId;

    /**
     * app key
     */
    private String appKey;

    /**
    * 可投广告数
    */
    private Integer putAdvertSum;

    /**
    * 创建人
    */
    private String creator;

    /**
     * 状态:0-启用，1-停用
     */
    private Integer status;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 更新时间
    */
    private Date gmtModified;

    /**广告位名称*/
    private String slotName;

    /**媒体名称*/
    private String appName;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getAppKey() {
        return appKey;
    }

    public void setAppKey(String appKey) {
        this.appKey = appKey;
    }

    public Integer getPutAdvertSum() {
        return putAdvertSum;
    }

    public void setPutAdvertSum(Integer putAdvertSum) {
        this.putAdvertSum = putAdvertSum;
    }

    public String getCreator() {
        return creator;
    }

    public void setCreator(String creator) {
        this.creator = creator;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getSlotName() {
        return slotName;
    }

    public void setSlotName(String slotName) {
        this.slotName = slotName;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }
}

==> risk-center-api-0.5.24-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/ForgeSlotCfgDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * 虚拟广告位配置表
 */
public class ForgeSlotCfgDto implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     *
     */
    private Long id;

    /**
     * 广告位ID
     */
    private Long slotId;

    /**
     * 媒体ID
     */
    private Long appId;

    /**
     * app key
     */
    private String appKey;

    /**
     * 可投广告数
     */
    private Integer putAdvertSum;

    /**
     * 消耗要求(分)
     */
    private Long consumeLimit;

    /**
     * 创建人
     */
    private String creator;

    /**
     * 状态:0-启用，1-停用
     */
    private Integer status;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 更新时间
     */
    private Date gmtModified;

    /**
     * 广告位名称
     */
    private String slotName;

    /**
     * 媒体名称
     */
    private String appName;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getAppKey() {
        return appKey;
    }

    public void setAppKey(String appKey) {
        this.appKey = appKey;
    }

    public Integer getPutAdvertSum() {
        return putAdvertSum;
    }

    public void setPutAdvertSum(Integer putAdvertSum) {
        this.putAdvertSum = putAdvertSum;
    }

    public Long getConsumeLimit() {
        return consumeLimit;
    }

    public void setConsumeLimit(Long consumeLimit) {
        this.consumeLimit = consumeLimit;
    }

    public String getCreator() {
        return creator;
    }

    public void setCreator(String creator) {
        this.creator = creator;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getSlotName() {
        return slotName;
    }

    public void setSlotName(String slotName) {
        this.slotName = slotName;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }
}
